@@ -101,9 +101,12 @@ class WSController(Controller):
             if '_' in self._cw.form:
                 del self._cw.form['_']
 
+            self._cw.content.seek(0)
+            content = self._cw.content.read()
+            self._cw.content.seek(0)
             args, kwargs = wsme.rest.args.get_args(
                 funcdef, args, {}, ParamsAdapter(self._cw.form), None,
-                self._cw.content.getvalue(), content_type
+                content, content_type
             )
 
             self._cw.set_content_type(restformat.content_type)
