@@ -32,7 +32,7 @@ class WSMERegistry(wsme.types.Registry):
         self.cwtypes = {
             'Boolean': bool,
             'Int': long,
-            'BitInt': long,
+            'BigInt': long,
             'Float': float,
             'Boolean': bool,
             'Decimal': decimal.Decimal,
